==> file-roller-2.26.2.tar.bz2: file-roller-2.26.2/src/fr-marshal.h <==

#ifndef __fr_marshal_MARSHAL_H__
#define __fr_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:INT (/home/paolo/workspace/file-roller/src/fr-marshal.list:1) */
#define fr_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:INT,INT (/home/paolo/workspace/file-roller/src/fr-marshal.list:2) */
extern void fr_marshal_VOID__INT_INT (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);

/* VOID:INT,POINTER (/home/paolo/workspace/file-roller/src/fr-marshal.list:3) */
extern void fr_marshal_VOID__INT_POINTER (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* VOID:POINTER (/home/paolo/workspace/file-roller/src/fr-marshal.list:4) */
#define fr_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:VOID (/home/paolo/workspace/file-roller/src/fr-marshal.list:5) */
#define fr_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:DOUBLE (/home/paolo/workspace/file-roller/src/fr-marshal.list:6) */
#define fr_marshal_VOID__DOUBLE	g_cclosure_marshal_VOID__DOUBLE

/* VOID:STRING (/home/paolo/workspace/file-roller/src/fr-marshal.list:7) */
#define fr_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:BOOL (/home/paolo/workspace/file-roller/src/fr-marshal.list:8) */
#define fr_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN
#define fr_marshal_VOID__BOOL	fr_marshal_VOID__BOOLEAN

G_END_DECLS

#endif /* __fr_marshal_MARSHAL_H__ */

==> file-roller-2.26.3.tar.bz2: file-roller-2.26.3/src/fr-marshal.h <==

#ifndef __fr_marshal_MARSHAL_H__
#define __fr_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:INT (../../src/fr-marshal.list:1) */
#define fr_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:INT,INT (../../src/fr-marshal.list:2) */
extern void fr_marshal_VOID__INT_INT (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);

/* VOID:INT,POINTER (../../src/fr-marshal.list:3) */
extern void fr_marshal_VOID__INT_POINTER (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* VOID:POINTER (../../src/fr-marshal.list:4) */
#define fr_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:VOID (../../src/fr-marshal.list:5) */
#define fr_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:DOUBLE (../../src/fr-marshal.list:6) */
#define fr_marshal_VOID__DOUBLE	g_cclosure_marshal_VOID__DOUBLE

/* VOID:STRING (../../src/fr-marshal.list:7) */
#define fr_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:BOOL (../../src/fr-marshal.list:8) */
#define fr_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN
#define fr_marshal_VOID__BOOL	fr_marshal_VOID__BOOLEAN

G_END_DECLS

#endif /* __fr_marshal_MARSHAL_H__ */
